"""
Travelling Wave Model Types

*** Autogenerated ***
Do not edit by hand!
"""

from functools import cached_property
from typing import ClassVar

from mhi.xml.node import ParametersBase
from mhi.xml.pscad.types import IntBool, Choice, UnitValue
from mhi.xml.pscad._project import project_lookup
from mhi.xml.pscad.component import UserCmp


# We do hokey things with 'types', so ...
# mypy: disable_error_code = "assignment, valid-type"
# pylint: disable=line-too-long, too-many-lines, missing-class-docstring


class TWMCmp(UserCmp):

    _defn: ClassVar[str] = ''
    Parameters: ClassVar[ParametersBase]

    @cached_property
    def parameters(self):
        """
        Return the paramlist backed `Parameter` object
        """

        return self.Parameters(self.find('paramlist'))


@project_lookup.defn('master:Line_Berg_Options')
class BergOptions(TWMCmp):
    _defn = 'master:Line_Berg_Options'

    class Parameters(ParametersBase):

        # Bergeron Line Model Options
        BDamp: IntBool = 0
        Interp1: IntBool = 1
        F1: UnitValue = '2000 [Hz]'
        TZ: UnitValue = '0.005 [ms]'
        TP: UnitValue = '0.005 [ms]'
        Inflen: IntBool = 0


@project_lookup.defn('master:Line_BusWork_1')
class BusWork1(TWMCmp):
    _defn = 'master:Line_BusWork_1'

    class Parameters(ParametersBase):

        # Bus Data
        BName: str = 'B1'
        Y: UnitValue = '5 [m]'
        X: UnitValue = '0 [m]'
        ShuntG: UnitValue = '1.0E-11 [mho/m]'
        RadiusC: UnitValue = '0.035306 [m]'
        thickness: UnitValue = '0.002921 [m]'
        DCResC: UnitValue = '0.0715198 [ohm/km]'
        PERMC: float = 1.0
        NC1: int = 1


@project_lookup.defn('master:Line_BusWork_3H')
class BusWork3H(TWMCmp):
    _defn = 'master:Line_BusWork_3H'

    class Parameters(ParametersBase):

        # Bus Data
        BName: str = 'B3H'
        Y: UnitValue = '5 [m]'
        X2: UnitValue = '0.5 [m]'
        X: UnitValue = '0 [m]'
        ShuntG: UnitValue = '1.0E-11 [mho/m]'
        RadiusC: UnitValue = '0.035306 [m]'
        thickness: UnitValue = '0.002921 [m]'
        DCResC: UnitValue = '0.0715198 [ohm/km]'
        PERMC: float = 1.0
        NC1: int = 1
        NC2: int = 2
        NC3: int = 3


@project_lookup.defn('master:Line_BusWork_3V')
class BusWork3V(TWMCmp):
    _defn = 'master:Line_BusWork_3V'

    class Parameters(ParametersBase):

        # Bus Data
        BName: str = 'B3V'
        Y: UnitValue = '5 [m]'
        Y2: UnitValue = '0.5 [m]'
        X: UnitValue = '0 [m]'
        ShuntG: UnitValue = '1.0E-11 [mho/m]'
        RadiusC: UnitValue = '0.035306 [m]'
        thickness: UnitValue = '0.002921 [m]'
        DCResC: UnitValue = '0.0715198 [ohm/km]'
        PERMC: float = 1.0
        NC1: int = 1
        NC2: int = 2
        NC3: int = 3


@project_lookup.defn('master:Line_Constants_Debug')
class ConstantsDebug(TWMCmp):
    _defn = 'master:Line_Constants_Debug'

    class Parameters(ParametersBase):

        # General Data
        DEBUG: IntBool = 0


@project_lookup.defn('master:Line_FreDep_Options')
class FreDepOptions(TWMCmp):
    _defn = 'master:Line_FreDep_Options'

    class Parameters(ParametersBase):

        # Frequency Dependent Model
        FS: UnitValue = '0.5 [Hz]'
        FE: UnitValue = '1.0E6 [Hz]'
        FT: UnitValue = '2000 [Hz]'
        ZMaxP: int = 20
        AMaxP: int = 20
        ZMaxE: UnitValue = '1.0 [%]'
        AMaxE: UnitValue = '1.0 [%]'
        Interp1: IntBool = 1
        Output: IntBool = 0
        W1: float = 1.0
        W2: float = 1000.0
        W3: float = 1.0
        Inflen: IntBool = 0


@project_lookup.defn('master:Line_FrePhase_Options')
class FrePhaseOptions(TWMCmp):
    _defn = 'master:Line_FrePhase_Options'

    class Parameters(ParametersBase):

        # Configuration
        Interp1: IntBool = 1
        Output: IntBool = 0
        Inflen: IntBool = 0

        # Curve Fitting
        FS: UnitValue = '0.01 [Hz]'
        FE: UnitValue = '1.0E6 [Hz]'
        Numf: Choice.ints(100, 200, 500, 1000) = 100
        YMaxP: int = 20
        YMaxE: UnitValue = '0.2 [%]'
        AMaxP: int = 20
        AMaxE: UnitValue = '0.2 [%]'
        MaxRPtol: float = 2000000.0
        W1: float = 1.0
        W2: float = 1.0
        W3: float = 1.0

        # Passivity Enforcement
        ET_PE: float = 1e-10
        NFP: Choice.ints(100, 500, 1000, 2000, 5000) = 1000
        FSP: UnitValue = '0.001 [Hz]'
        MER_PE: float = 2.0
        MIT_PE: int = 5
        FEP: UnitValue = '1E6 [Hz]'
        FDIS: Choice.enum('Log', 'Linear', 'Log + Linear', start=1) = 3
        CPASS: Choice.enum('Disable', 'Scan only', 'Enforcement') = 0

        # DC Correction
        DCenab: IntBool = 0
        DCCOR: Choice.enum('Functional Form', 'Add Pole/Residue', start=1) = 1
        shntcab: UnitValue = '1.0E-9 [mho/m]'
        enablf: IntBool = 1


@project_lookup.defn('master:Line_Ground')
class Ground(TWMCmp):
    _defn = 'master:Line_Ground'

    class Parameters(ParametersBase):

        # Configuration
        EarthForm2: Choice({'0': 'Analytical approximation (Deri-Semlyen)', '2': 'Direct numerical integration'}) = 0
        EarthForm: Choice({'3': 'Analytical approximation (Saad)', '0': 'Analytical approximation (Wedepohl)', '2': 'Direct numerical integration'}) = 2
        EarthForm3: Choice({'0': 'Analytical approximation (Ametanil)', '2': 'Analytical approximation (Lucca)'}) = 2
        GrRho: Choice.enum('constant resistivity', 'frequency-dependent conductivity (Portela)') = 0
        GRRES: UnitValue = '100.0 [ohm*m]'
        GPERM: float = 1.0
        K0: UnitValue = '0.001 [S/m]'
        K1: UnitValue = '0.01 [S/m]'
        alpha: float = 0.7
        GRP: float = 10.0


@project_lookup.defn('master:Line_ManualYZ')
class ManualYZ(TWMCmp):
    _defn = 'master:Line_ManualYZ'

    class Parameters(ParametersBase):

        # COPIED DATA FROM ABOVE
        Name: str = ''
        NCond: int = 3

        # Manual YZ Data Configuration
        PU: Choice.enum('R,Xl,Xc (pu/m)', 'R,Xl,Xc (ohm/m)', 'Zsurge and Travel Time', 'R,X,B (pu/m)', 'Y,Z (mho/m,ohm/m)', 'Y,Z (multiple frequencies)') = 0
        Estim: Choice.enum('Enter 0 Sequence Data', 'Estimate 0 Sequence Data', 'Same as Positive Sequence') = 0
        REst: float = 10.15
        ZEst: float = 1.915
        TEst: float = 1.36
        LONGLN: IntBool = 0

        # R,Xl,Xc Data Entry [pu/m]
        VR: UnitValue = '230 [kV]'
        MVA: UnitValue = '100 [MVA]'
        RPUP: UnitValue = '6.76e-8 [pu/m]'
        XLPUP: UnitValue = '9.6e-7 [pu/m]'
        XCPUP: UnitValue = '5.78e5 [pu*m]'
        RPUZ: UnitValue = '6.86e-7 [pu/m]'
        XLPUZ: UnitValue = '2.5e-6 [pu/m]'
        XCPUZ: UnitValue = '8.14e5 [pu*m]'
        RPUZM: UnitValue = '5.35e-7 [pu/m]'
        XLPUZM: UnitValue = '6.37e-7 [pu/m]'
        XCPUZM: UnitValue = '5.4e7 [pu*m]'

        # R,Xl,Xc Data Entry [ohm/m]
        RP: UnitValue = '3.576e-5 [ohm/m]'
        XLP: UnitValue = '5.078e-4 [ohm/m]'
        XCP: UnitValue = '305.8 [Mohm*m]'
        RZ: UnitValue = '3.63e-4 [ohm/m]'
        XLZ: UnitValue = '1.323e-3 [ohm/m]'
        XCZ: UnitValue = '430.6 [Mohm*m]'
        RZM: UnitValue = '2.83e-4 [ohm/m]'
        XLZM: UnitValue = '3.37e-4 [ohm/m]'
        XCZM: UnitValue = '28560.0 [Mohm*m]'

        # Zsurge and Travel Time
        RTP: UnitValue = '3.576e-5 [ohm/m]'
        TTP: UnitValue = '3.4185e-9 [s/m]'
        ZTP: UnitValue = '394.06 [ohm]'
        RTZ: UnitValue = '3.63e-4 [ohm/m]'
        TTZ: UnitValue = '4.65e-9 [s/m]'
        ZTZ: UnitValue = '754.77 [ohm]'
        RTZM: UnitValue = '2.83e-4 [ohm/m]'
        TTZM: UnitValue = '0.288e-9 [s/m]'
        ZTZM: UnitValue = '3102.4 [ohm]'

        # R,X,B Data Entry [pu/m]
        VR2: UnitValue = '230 [kV]'
        MVA2: UnitValue = '100 [MVA]'
        RPUP2: UnitValue = '6.76e-8 [pu/m]'
        XLPUP2: UnitValue = '9.6e-7 [pu/m]'
        BPUP2: UnitValue = '1.73e-6 [pu/m]'
        RPUZ2: UnitValue = '6.86e-7 [pu/m]'
        XLPUZ2: UnitValue = '2.5e-6 [pu/m]'
        BPUZ2: UnitValue = '1.23e-6 [pu/m]'
        RPUZM2: UnitValue = '5.35e-7 [pu/m]'
        XLPUZM2: UnitValue = '6.37e-7 [pu/m]'
        BPUZM2: UnitValue = '1.85e-8 [pu/m]'

        # Y,Z Direct Entry
        fname: str = 'inputYZ.txt'
        path: Choice.enum('Relative path', 'Absolute path') = 0
        dformat: Choice.enum('Per metre', 'Total') = 0

        # Y,Z Direct Entry (Multiple Frequencies)
        fname2: str = 'inputYZ.txt'
        path2: Choice.enum('Relative path', 'Absolute path') = 0


@project_lookup.defn('master:Line_Out_Disp')
class OutDisp(TWMCmp):
    _defn = 'master:Line_Out_Disp'

    class Parameters(ParametersBase):

        # Configuration
        DataF: UnitValue = '60.0 [Hz]'
        Zero_Tol: float = 1e-19
        Vbase: UnitValue = '230.0 [kV]'
        MVAbase: UnitValue = '100.0 [MVA]'
        picomp: IntBool = 0
        Rip: UnitValue = '1.0E5 [ohm]'
        EMM: Choice.enum('No (Classical formulas)', 'Yes (MoM-SO Algorithm)') = 0
        OMM: int = 3


@project_lookup.defn('master:Line_Tower_1')
class Tower1(TWMCmp):
    _defn = 'master:Line_Tower_1'

    class Parameters(ParametersBase):

        # Configuration
        X: UnitValue = '0.0 [m]'
        Y: UnitValue = '30.0 [m]'
        YG: UnitValue = '10.0 [m]'
        XG: UnitValue = '10.0 [m]'
        SHSag: IntBool = 0
        ShuntG: UnitValue = '1.0E-11 [mho/m]'
        TName: str = 'N1'

        # Conductor Data
        CName: str = 'chukar'
        CDataType: Choice.enum('from library file', 'direct') = 1
        CLName: str = '..\\conductor.clb'
        Hollow: Choice.enum('solid core', 'hollow', 'stranded') = 0
        RadiusC: UnitValue = '0.0203454 [m]'
        RadiusCin: UnitValue = '0.0 [m]'
        num_tot_strnd: int = 19
        num_out_strnd: int = 12
        RadiusS: UnitValue = '0.003 [m]'
        DCResC: UnitValue = '0.03206 [ohm/km]'
        PERMC: float = 1.0
        SAGC: UnitValue = '10.0 [m]'
        NCondB: Choice.ints(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15) = 1
        BundSym: Choice.enum('symmetrical', 'asymmetrical') = 0
        BSP: UnitValue = '0.4572 [m]'
        SHBund: IntBool = 1

        # Asymmetrical Bundling Position Data
        XB1: UnitValue = '-0.1 [m]'
        YB1: UnitValue = '0.1 [m]'
        XB2: UnitValue = '-0.1 [m]'
        YB2: UnitValue = '0.1 [m]'
        XB3: UnitValue = '-0.1 [m]'
        YB3: UnitValue = '0.1 [m]'
        XB4: UnitValue = '-0.1 [m]'
        YB4: UnitValue = '0.1 [m]'
        XB5: UnitValue = '-0.1 [m]'
        YB5: UnitValue = '0.1 [m]'
        XB6: UnitValue = '-0.1 [m]'
        YB6: UnitValue = '0.1 [m]'
        XB7: UnitValue = '-0.1 [m]'
        YB7: UnitValue = '0.1 [m]'
        XB8: UnitValue = '-0.1 [m]'
        YB8: UnitValue = '0.1 [m]'
        XB9: UnitValue = '-0.1 [m]'
        YB9: UnitValue = '0.1 [m]'
        XB10: UnitValue = '-0.1 [m]'
        YB10: UnitValue = '0.1 [m]'
        XB11: UnitValue = '-0.1 [m]'
        YB11: UnitValue = '0.1 [m]'
        XB12: UnitValue = '-0.1 [m]'
        YB12: UnitValue = '0.1 [m]'
        XB13: UnitValue = '-0.1 [m]'
        YB13: UnitValue = '0.1 [m]'
        XB14: UnitValue = '-0.1 [m]'
        YB14: UnitValue = '0.1 [m]'
        XB15: UnitValue = '-0.1 [m]'
        YB15: UnitValue = '0.1 [m]'

        # Ground Wire Data
        NG: Choice.ints(0, 1, 2) = 1
        GDataType: Choice.enum('from library file', 'direct') = 1
        GLName: str = '..\\conductor.clb'
        GWSame: IntBool = 1
        ElimGW: IntBool = 1
        GName: str = '1/2_HighStrengthSteel'
        G2Name: str = '1/2_HighStrengthSteel'
        RadiusG: UnitValue = '0.0055245 [m]'
        DCResG: UnitValue = '2.8645 [ohm/km]'
        PERMG: float = 1.0
        RadiusG2: UnitValue = '0.0055245 [m]'
        DCResG2: UnitValue = '2.8645 [ohm/km]'
        PERMG2: float = 1.0
        SAGG: UnitValue = '10.0 [m]'

        # Phase/Node Connection Information
        NC1: int = 1
        NG1: int = 2
        NG2: int = 3


@project_lookup.defn('master:Line_Tower_12_Vert')
class Tower12Vert(TWMCmp):
    _defn = 'master:Line_Tower_12_Vert'

    class Parameters(ParametersBase):

        # Configuration
        X: UnitValue = '0.0 [m]'
        Y: UnitValue = '30.0 [m]'
        XC: UnitValue = '10.0 [m]'
        Y2: UnitValue = '5.0 [m]'
        Y3: UnitValue = '15.0 [m]'
        YG: UnitValue = '30.0 [m]'
        XG: UnitValue = '10.0 [m]'
        SHSag: IntBool = 0
        Transp: Choice.enum('disabled', 'enabled (all together)', 'enabled (each group separately)') = 0
        ShuntG: UnitValue = '1.0E-11 [mho/m]'
        TName: str = 'N12'

        # Conductor Data
        CName: str = 'chukar'
        CDataType: Choice.enum('from library file', 'direct') = 1
        CLName: str = '..\\conductor.clb'
        Hollow: Choice.enum('solid core', 'hollow', 'stranded') = 0
        RadiusC: UnitValue = '0.0203454 [m]'
        RadiusCin: UnitValue = '0.0 [m]'
        num_tot_strnd: int = 19
        num_out_strnd: int = 12
        RadiusS: UnitValue = '0.003 [m]'
        DCResC: UnitValue = '0.03206 [ohm/km]'
        PERMC: float = 1.0
        SAGC: UnitValue = '10.0 [m]'
        NCondB: Choice.ints(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15) = 1
        BundSym: Choice.enum('symmetrical', 'asymmetrical') = 0
        BSP: UnitValue = '0.4572 [m]'
        SHBund: IntBool = 1

        # Asymmetrical Bundling Position Data
        XB1: UnitValue = '-0.1 [m]'
        YB1: UnitValue = '0.1 [m]'
        XB2: UnitValue = '-0.1 [m]'
        YB2: UnitValue = '0.1 [m]'
        XB3: UnitValue = '-0.1 [m]'
        YB3: UnitValue = '0.1 [m]'
        XB4: UnitValue = '-0.1 [m]'
        YB4: UnitValue = '0.1 [m]'
        XB5: UnitValue = '-0.1 [m]'
        YB5: UnitValue = '0.1 [m]'
        XB6: UnitValue = '-0.1 [m]'
        YB6: UnitValue = '0.1 [m]'
        XB7: UnitValue = '-0.1 [m]'
        YB7: UnitValue = '0.1 [m]'
        XB8: UnitValue = '-0.1 [m]'
        YB8: UnitValue = '0.1 [m]'
        XB9: UnitValue = '-0.1 [m]'
        YB9: UnitValue = '0.1 [m]'
        XB10: UnitValue = '-0.1 [m]'
        YB10: UnitValue = '0.1 [m]'
        XB11: UnitValue = '-0.1 [m]'
        YB11: UnitValue = '0.1 [m]'
        XB12: UnitValue = '-0.1 [m]'
        YB12: UnitValue = '0.1 [m]'
        XB13: UnitValue = '-0.1 [m]'
        YB13: UnitValue = '0.1 [m]'
        XB14: UnitValue = '-0.1 [m]'
        YB14: UnitValue = '0.1 [m]'
        XB15: UnitValue = '-0.1 [m]'
        YB15: UnitValue = '0.1 [m]'

        # Ground Wire Data
        NG: Choice.ints(0, 1, 2) = 2
        GDataType: Choice.enum('from library file', 'direct') = 1
        GLName: str = '..\\conductor.clb'
        GWSame: IntBool = 1
        ElimGW: IntBool = 1
        GName: str = '1/2_HighStrengthSteel'
        G2Name: str = '1/2_HighStrengthSteel'
        RadiusG: UnitValue = '0.0055245 [m]'
        DCResG: UnitValue = '2.8645 [ohm/km]'
        PERMG: float = 1.0
        RadiusG2: UnitValue = '0.0055245 [m]'
        DCResG2: UnitValue = '2.8645 [ohm/km]'
        PERMG2: float = 1.0
        SAGG: UnitValue = '10.0 [m]'

        # Phase/Node Connection Information
        NC1: int = 1
        NC2: int = 2
        NC3: int = 3
        NC4: int = 4
        NC5: int = 5
        NC6: int = 6
        NC7: int = 7
        NC8: int = 8
        NC9: int = 9
        NC10: int = 10
        NC11: int = 11
        NC12: int = 12
        NG1: int = 13
        NG2: int = 14


@project_lookup.defn('master:Line_Tower_2_Flat')
class Tower2Flat(TWMCmp):
    _defn = 'master:Line_Tower_2_Flat'

    class Parameters(ParametersBase):

        # Configuration
        X: UnitValue = '0.0 [m]'
        Y: UnitValue = '30.0 [m]'
        XC: UnitValue = '10.0 [m]'
        YG: UnitValue = '10.0 [m]'
        XG: UnitValue = '10.0 [m]'
        SHSag: IntBool = 0
        Transp: IntBool = 0
        ShuntG: UnitValue = '1.0E-11 [mho/m]'
        TName: str = 'DC2'

        # Conductor Data
        CName: str = 'chukar'
        CDataType: Choice.enum('from library file', 'direct') = 1
        CLName: str = '..\\conductor.clb'
        Hollow: Choice.enum('solid core', 'hollow', 'stranded') = 0
        RadiusC: UnitValue = '0.0203454 [m]'
        RadiusCin: UnitValue = '0.0 [m]'
        num_tot_strnd: int = 19
        num_out_strnd: int = 12
        RadiusS: UnitValue = '0.003 [m]'
        DCResC: UnitValue = '0.03206 [ohm/km]'
        PERMC: float = 1.0
        SAGC: UnitValue = '10.0 [m]'
        NCondB: Choice.ints(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15) = 1
        BundSym: Choice.enum('symmetrical', 'asymmetrical') = 0
        BSP: UnitValue = '0.4572 [m]'
        SHBund: IntBool = 1

        # Asymmetrical Bundling Position Data
        XB1: UnitValue = '-0.1 [m]'
        YB1: UnitValue = '0.1 [m]'
        XB2: UnitValue = '-0.1 [m]'
        YB2: UnitValue = '0.1 [m]'
        XB3: UnitValue = '-0.1 [m]'
        YB3: UnitValue = '0.1 [m]'
        XB4: UnitValue = '-0.1 [m]'
        YB4: UnitValue = '0.1 [m]'
        XB5: UnitValue = '-0.1 [m]'
        YB5: UnitValue = '0.1 [m]'
        XB6: UnitValue = '-0.1 [m]'
        YB6: UnitValue = '0.1 [m]'
        XB7: UnitValue = '-0.1 [m]'
        YB7: UnitValue = '0.1 [m]'
        XB8: UnitValue = '-0.1 [m]'
        YB8: UnitValue = '0.1 [m]'
        XB9: UnitValue = '-0.1 [m]'
        YB9: UnitValue = '0.1 [m]'
        XB10: UnitValue = '-0.1 [m]'
        YB10: UnitValue = '0.1 [m]'
        XB11: UnitValue = '-0.1 [m]'
        YB11: UnitValue = '-0.1 [m]'
        XB12: UnitValue = '-0.1 [m]'
        YB12: UnitValue = '-0.1 [m]'
        XB13: UnitValue = '-0.1 [m]'
        YB13: UnitValue = '-0.1 [m]'
        XB14: UnitValue = '-0.1 [m]'
        YB14: UnitValue = '-0.1 [m]'
        XB15: UnitValue = '-0.1 [m]'
        YB15: UnitValue = '-0.1 [m]'

        # Ground Wire Data
        NG: Choice.ints(0, 1, 2) = 2
        GDataType: Choice.enum('from library file', 'direct') = 1
        GLName: str = '..\\conductor.clb'
        GWSame: IntBool = 1
        ElimGW: IntBool = 1
        GName: str = '1/2_HighStrengthSteel'
        G2Name: str = '1/2_HighStrengthSteel'
        RadiusG: UnitValue = '0.0055245 [m]'
        DCResG: UnitValue = '2.8645 [ohm/km]'
        PERMG: float = 1.0
        RadiusG2: UnitValue = '0.0055245 [m]'
        DCResG2: UnitValue = '2.8645 [ohm/km]'
        PERMG2: float = 1.0
        SAGG: UnitValue = '10.0 [m]'

        # Phase/Node Connection Information
        NC1: int = 1
        NC2: int = 2
        NG1: int = 3
        NG2: int = 4


@project_lookup.defn('master:Line_Tower_3-Flat')
class Tower3Flat(TWMCmp):
    _defn = 'master:Line_Tower_3-Flat'

    class Parameters(ParametersBase):

        # Configuration
        X: UnitValue = '0.0 [m]'
        Y: UnitValue = '30.0 [m]'
        XC: UnitValue = '10.0 [m]'
        YG: UnitValue = '10.0 [m]'
        XG: UnitValue = '10.0 [m]'
        SHSag: IntBool = 0
        Transp: IntBool = 0
        ShuntG: UnitValue = '1.0e-11 [mho/m]'
        TName: str = '3L1'

        # Conductor Data
        CName: str = 'chukar'
        CDataType: Choice.enum('from library file', 'direct') = 1
        CLName: str = '..\\conductor.clb'
        Hollow: Choice.enum('solid core', 'hollow', 'stranded') = 0
        RadiusC: UnitValue = '0.0203454 [m]'
        RadiusCin: UnitValue = '0.0 [m]'
        num_tot_strnd: int = 19
        num_out_strnd: int = 12
        RadiusS: UnitValue = '0.003 [m]'
        DCResC: UnitValue = '0.03206 [ohm/km]'
        PERMC: float = 1.0
        SAGC: UnitValue = '10.0 [m]'
        NCondB: Choice.ints(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15) = 1
        BundSym: Choice.enum('symmetrical', 'asymmetrical') = 0
        BSP: UnitValue = '0.4572 [m]'
        SHBund: IntBool = 1

        # Ground Wire Data
        NG: Choice.ints(0, 1, 2) = 2
        GDataType: Choice.enum('from library file', 'direct') = 1
        GLName: str = '..\\conductor.clb'
        GWSame: IntBool = 1
        ElimGW: IntBool = 1
        GName: str = '1/2_HighStrengthSteel'
        G2Name: str = '1/2_HighStrengthSteel'
        RadiusG: UnitValue = '0.0055245 [m]'
        DCResG: UnitValue = '2.8645 [ohm/km]'
        PERMG: float = 1.0
        RadiusG2: UnitValue = '0.0055245 [m]'
        DCResG2: UnitValue = '2.8645 [ohm/km]'
        PERMG2: float = 1.0
        SAGG: UnitValue = '10 [m]'

        # Asymmetrical Bundling Position Data
        XB1: UnitValue = '-0.1 [m]'
        YB1: UnitValue = '0.1 [m]'
        XB2: UnitValue = '-0.1 [m]'
        YB2: UnitValue = '0.1 [m]'
        XB3: UnitValue = '-0.1 [m]'
        YB3: UnitValue = '0.1 [m]'
        XB4: UnitValue = '-0.1 [m]'
        YB4: UnitValue = '0.1 [m]'
        XB5: UnitValue = '-0.1 [m]'
        YB5: UnitValue = '0.1 [m]'
        XB6: UnitValue = '-0.1 [m]'
        YB6: UnitValue = '0.1 [m]'
        XB7: UnitValue = '-0.1 [m]'
        YB7: UnitValue = '0.1 [m]'
        XB8: UnitValue = '-0.1 [m]'
        YB8: UnitValue = '0.1 [m]'
        XB9: UnitValue = '-0.1 [m]'
        YB9: UnitValue = '0.1 [m]'
        XB10: UnitValue = '-0.1 [m]'
        YB10: UnitValue = '0.1 [m]'
        XB11: UnitValue = '-0.1 [m]'
        YB11: UnitValue = '-0.1 [m]'
        XB12: UnitValue = '-0.1 [m]'
        YB12: UnitValue = '-0.1 [m]'
        XB13: UnitValue = '-0.1 [m]'
        YB13: UnitValue = '-0.1 [m]'
        XB14: UnitValue = '-0.1 [m]'
        YB14: UnitValue = '-0.1 [m]'
        XB15: UnitValue = '-0.1 [m]'
        YB15: UnitValue = '-0.1 [m]'

        # Phase/Node Connection Information
        NC1: int = 1
        NC2: int = 2
        NC3: int = 3
        NG1: int = 4
        NG2: int = 5


@project_lookup.defn('master:Line_Tower_3_Concent')
class Tower3Concent(TWMCmp):
    _defn = 'master:Line_Tower_3_Concent'

    class Parameters(ParametersBase):

        # Configuration
        X: UnitValue = '0.0 [m]'
        side: Choice({'true': 'the right', 'false': 'the left'}) = 'false'
        Y: UnitValue = '30.0 [m]'
        X2: UnitValue = '2.0 [m]'
        Y2: UnitValue = '5.0 [m]'
        YG: UnitValue = '15.0 [m]'
        XG: UnitValue = '10.0 [m]'
        SHSag: IntBool = 0
        Transp: IntBool = 0
        ShuntG: UnitValue = '1.0E-11 [mho/m]'
        TName: str = '3LConc'
        XG_2: UnitValue = '0.0 [m]'

        # Conductor Data
        CName: str = 'chukar'
        CDataType: Choice.enum('from library file', 'direct') = 1
        CLName: str = '..\\conductor.clb'
        Hollow: Choice.enum('solid core', 'hollow', 'stranded') = 0
        RadiusC: UnitValue = '0.0203454 [m]'
        RadiusCin: UnitValue = '0.0 [m]'
        num_tot_strnd: int = 19
        num_out_strnd: int = 12
        RadiusS: UnitValue = '0.003 [m]'
        DCResC: UnitValue = '0.03206 [ohm/km]'
        PERMC: float = 1.0
        SAGC: UnitValue = '10.0 [m]'
        NCondB: Choice.ints(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15) = 1
        BundSym: Choice.enum('symmetrical', 'asymmetrical') = 0
        BSP: UnitValue = '0.4572 [m]'
        SHBund: IntBool = 1

        # Asymmetrical Bundling Position Data
        XB1: UnitValue = '-0.1 [m]'
        YB1: UnitValue = '0.1 [m]'
        XB2: UnitValue = '-0.1 [m]'
        YB2: UnitValue = '0.1 [m]'
        XB3: UnitValue = '-0.1 [m]'
        YB3: UnitValue = '0.1 [m]'
        XB4: UnitValue = '-0.1 [m]'
        YB4: UnitValue = '0.1 [m]'
        XB5: UnitValue = '-0.1 [m]'
        YB5: UnitValue = '0.1 [m]'
        XB6: UnitValue = '-0.1 [m]'
        YB6: UnitValue = '0.1 [m]'
        XB7: UnitValue = '-0.1 [m]'
        YB7: UnitValue = '0.1 [m]'
        XB8: UnitValue = '-0.1 [m]'
        YB8: UnitValue = '0.1 [m]'
        XB9: UnitValue = '-0.1 [m]'
        YB9: UnitValue = '0.1 [m]'
        XB10: UnitValue = '-0.1 [m]'
        YB10: UnitValue = '0.1 [m]'
        XB11: UnitValue = '-0.1 [m]'
        YB11: UnitValue = '0.1 [m]'
        XB12: UnitValue = '-0.1 [m]'
        YB12: UnitValue = '0.1 [m]'
        XB13: UnitValue = '-0.1 [m]'
        YB13: UnitValue = '0.1 [m]'
        XB14: UnitValue = '-0.1 [m]'
        YB14: UnitValue = '0.1 [m]'
        XB15: UnitValue = '-0.1 [m]'
        YB15: UnitValue = '0.1 [m]'

        # Ground Wire Data
        NG: Choice.ints(0, 1, 2) = 2
        GDataType: Choice.enum('from library file', 'direct') = 1
        GWSame: IntBool = 1
        GLName: str = '..\\conductor.clb'
        ElimGW: IntBool = 1
        GName: str = '1/2_HighStrengthSteel'
        G2Name: str = '1/2_HighStrengthSteel'
        RadiusG: UnitValue = '0.0055245 [m]'
        DCResG: UnitValue = '2.8645 [ohm/km]'
        PERMG: float = 1.0
        RadiusG2: UnitValue = '0.0055245 [m]'
        DCResG2: UnitValue = '2.8645 [ohm/km]'
        PERMG2: float = 1.0
        SAGG: UnitValue = '10.0 [m]'

        # Phase/Node Connection Information
        NC1: int = 1
        NC2: int = 2
        NC3: int = 3
        NG1: int = 4
        NG2: int = 5


@project_lookup.defn('master:Line_Tower_3_Delta')
class Tower3Delta(TWMCmp):
    _defn = 'master:Line_Tower_3_Delta'

    class Parameters(ParametersBase):

        # Configuration
        X: UnitValue = '0.0 [m]'
        Y: UnitValue = '30.0 [m]'
        XC: UnitValue = '10.0 [m]'
        Y2: UnitValue = '5.0 [m]'
        YG: UnitValue = '10.0 [m]'
        XG: UnitValue = '10.0 [m]'
        SHSag: IntBool = 0
        Transp: IntBool = 0
        ShuntG: UnitValue = '1.0E-11 [mho/m]'
        TName: str = '3H5'
        XG_2: UnitValue = '0.0 [m]'

        # Conductor Data
        CName: str = 'chukar'
        CDataType: Choice.enum('from library file', 'direct') = 1
        CLName: str = '..\\conductor.clb'
        Hollow: Choice.enum('solid core', 'hollow', 'stranded') = 0
        RadiusC: UnitValue = '0.0203454 [m]'
        RadiusCin: UnitValue = '0.0 [m]'
        num_tot_strnd: int = 19
        num_out_strnd: int = 12
        RadiusS: UnitValue = '0.003 [m]'
        DCResC: UnitValue = '0.03206 [ohm/km]'
        PERMC: float = 1.0
        SAGC: UnitValue = '10.0 [m]'
        NCondB: Choice.ints(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15) = 1
        BundSym: Choice.enum('symmetrical', 'asymmetrical') = 0
        BSP: UnitValue = '0.4572 [m]'
        SHBund: IntBool = 1

        # Asymmetrical Bundling Position Data
        XB1: UnitValue = '-0.1 [m]'
        YB1: UnitValue = '0.1 [m]'
        XB2: UnitValue = '-0.1 [m]'
        YB2: UnitValue = '0.1 [m]'
        XB3: UnitValue = '-0.1 [m]'
        YB3: UnitValue = '0.1 [m]'
        XB4: UnitValue = '-0.1 [m]'
        YB4: UnitValue = '0.1 [m]'
        XB5: UnitValue = '-0.1 [m]'
        YB5: UnitValue = '0.1 [m]'
        XB6: UnitValue = '-0.1 [m]'
        YB6: UnitValue = '0.1 [m]'
        XB7: UnitValue = '-0.1 [m]'
        YB7: UnitValue = '0.1 [m]'
        XB8: UnitValue = '-0.1 [m]'
        YB8: UnitValue = '0.1 [m]'
        XB9: UnitValue = '-0.1 [m]'
        YB9: UnitValue = '0.1 [m]'
        XB10: UnitValue = '-0.1 [m]'
        YB10: UnitValue = '0.1 [m]'
        XB11: UnitValue = '-0.1 [m]'
        YB11: UnitValue = '0.1 [m]'
        XB12: UnitValue = '-0.1 [m]'
        YB12: UnitValue = '0.1 [m]'
        XB13: UnitValue = '-0.1 [m]'
        YB13: UnitValue = '0.1 [m]'
        XB14: UnitValue = '-0.1 [m]'
        YB14: UnitValue = '0.1 [m]'
        XB15: UnitValue = '-0.1 [m]'
        YB15: UnitValue = '0.1 [m]'

        # Ground Wire Data
        NG: Choice.ints(0, 1, 2) = 2
        GDataType: Choice.enum('from library file', 'direct') = 1
        GLName: str = '..\\conductor.clb'
        GWSame: IntBool = 1
        ElimGW: IntBool = 1
        GName: str = '1/2_HighStrengthSteel'
        G2Name: str = '1/2_HighStrengthSteel'
        RadiusG: UnitValue = '0.0055245 [m]'
        DCResG: UnitValue = '2.8645 [ohm/km]'
        PERMG: float = 1.0
        RadiusG2: UnitValue = '0.0055245 [m]'
        DCResG2: UnitValue = '2.8645 [ohm/km]'
        PERMG2: float = 1.0
        SAGG: UnitValue = '10.0 [m]'

        # Phase/Node Connection Information
        NC1: int = 1
        NC2: int = 2
        NC3: int = 3
        NG1: int = 4
        NG2: int = 5


@project_lookup.defn('master:Line_Tower_3_Offset')
class Tower3Offset(TWMCmp):
    _defn = 'master:Line_Tower_3_Offset'

    class Parameters(ParametersBase):

        # Configuration
        X: UnitValue = '0.0 [m]'
        side: Choice({'true': 'the right', 'false': 'the left'}) = 'true'
        Y: UnitValue = '30.0 [m]'
        X2: UnitValue = '2.0 [m]'
        Y2: UnitValue = '5.0 [m]'
        YG: UnitValue = '15.0 [m]'
        XG: UnitValue = '10.0 [m]'
        SHSag: IntBool = 0
        Transp: Choice.enum('diabled', 'enabled') = 0
        ShuntG: UnitValue = '1.0E-11 [mho/m]'
        TName: str = '3LOffset'
        XG_2: UnitValue = '0.0 [m]'

        # Conductor Data
        CName: str = 'chukar'
        CDataType: Choice.enum('from library file', 'direct') = 1
        CLName: str = '..\\conductor.clb'
        Hollow: Choice.enum('solid core', 'hollow', 'stranded') = 0
        RadiusC: UnitValue = '0.020345 [m]'
        RadiusCin: UnitValue = '0.0 [m]'
        num_tot_strnd: int = 19
        num_out_strnd: int = 12
        RadiusS: UnitValue = '0.003 [m]'
        DCResC: UnitValue = '0.03206 [ohm/km]'
        PERMC: float = 1.0
        SAGC: UnitValue = '10.0 [m]'
        NCondB: Choice.ints(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15) = 1
        BundSym: Choice.enum('symmetrical', 'asymmetrical') = 0
        BSP: UnitValue = '0.4572 [m]'
        SHBund: IntBool = 1

        # Asymmetrical Bundling Position Data
        XB1: UnitValue = '-0.1 [m]'
        YB1: UnitValue = '0.1 [m]'
        XB2: UnitValue = '-0.1 [m]'
        YB2: UnitValue = '0.1 [m]'
        XB3: UnitValue = '-0.1 [m]'
        YB3: UnitValue = '0.1 [m]'
        XB4: UnitValue = '-0.1 [m]'
        YB4: UnitValue = '0.1 [m]'
        XB5: UnitValue = '-0.1 [m]'
        YB5: UnitValue = '0.1 [m]'
        XB6: UnitValue = '-0.1 [m]'
        YB6: UnitValue = '0.1 [m]'
        XB7: UnitValue = '-0.1 [m]'
        YB7: UnitValue = '0.1 [m]'
        XB8: UnitValue = '-0.1 [m]'
        YB8: UnitValue = '0.1 [m]'
        XB9: UnitValue = '-0.1 [m]'
        YB9: UnitValue = '0.1 [m]'
        XB10: UnitValue = '-0.1 [m]'
        YB10: UnitValue = '0.1 [m]'
        XB11: UnitValue = '-0.1 [m]'
        YB11: UnitValue = '0.1 [m]'
        XB12: UnitValue = '-0.1 [m]'
        YB12: UnitValue = '0.1 [m]'
        XB13: UnitValue = '-0.1 [m]'
        YB13: UnitValue = '0.1 [m]'
        XB14: UnitValue = '-0.1 [m]'
        YB14: UnitValue = '0.1 [m]'
        XB15: UnitValue = '-0.1 [m]'
        YB15: UnitValue = '0.1 [m]'

        # Ground Wire Data
        NG: Choice.ints(0, 1, 2) = 2
        GDataType: Choice.enum('from library file', 'direct') = 1
        GWSame: IntBool = 1
        GLName: str = '..\\conductor.clb'
        ElimGW: IntBool = 1
        GName: str = '1/2_HighStrengthSteel'
        G2Name: str = '1/2_HighStrengthSteel'
        RadiusG: UnitValue = '0.0055245 [m]'
        DCResG: UnitValue = '2.8645 [ohm/km]'
        PERMG: float = 1.0
        RadiusG2: UnitValue = '0.0055245 [m]'
        DCResG2: UnitValue = '2.8645 [ohm/km]'
        PERMG2: float = 1.0
        SAGG: UnitValue = '10.0 [m]'

        # Phase/Node Connection Information
        NC1: int = 1
        NC2: int = 2
        NC3: int = 3
        NG1: int = 4
        NG2: int = 5


@project_lookup.defn('master:Line_Tower_3_Vert')
class Tower3Vert(TWMCmp):
    _defn = 'master:Line_Tower_3_Vert'

    class Parameters(ParametersBase):

        # Configuration
        X: UnitValue = '0.0 [m]'
        Y: UnitValue = '30.0 [m]'
        Y2: UnitValue = '5.0 [m]'
        YG: UnitValue = '15.0 [m]'
        XG: UnitValue = '10.0 [m]'
        SHSag: IntBool = 0
        Transp: IntBool = 0
        ShuntG: UnitValue = '1.0E-11 [mho/m]'
        TName: str = '3LVert'
        XG_2: UnitValue = '0.0 [m]'

        # Conductor Data
        CName: str = 'chukar'
        CDataType: Choice.enum('from library file', 'direct') = 1
        CLName: str = '..\\conductor.clb'
        Hollow: Choice.enum('solid core', 'hollow', 'stranded') = 0
        RadiusC: UnitValue = '0.0203454 [m]'
        RadiusCin: UnitValue = '0.0 [m]'
        num_tot_strnd: int = 19
        num_out_strnd: int = 12
        RadiusS: UnitValue = '0.003 [m]'
        DCResC: UnitValue = '0.03206 [ohm/km]'
        PERMC: float = 1.0
        SAGC: UnitValue = '10.0 [m]'
        NCondB: Choice.ints(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15) = 1
        BundSym: Choice.enum('symmetrical', 'asymmetrical') = 0
        BSP: UnitValue = '0.4572 [m]'
        SHBund: IntBool = 1

        # Asymmetrical Bundling Position Data
        XB1: UnitValue = '-0.1 [m]'
        YB1: UnitValue = '0.1 [m]'
        XB2: UnitValue = '-0.1 [m]'
        YB2: UnitValue = '0.1 [m]'
        XB3: UnitValue = '-0.1 [m]'
        YB3: UnitValue = '0.1 [m]'
        XB4: UnitValue = '-0.1 [m]'
        YB4: UnitValue = '0.1 [m]'
        XB5: UnitValue = '-0.1 [m]'
        YB5: UnitValue = '0.1 [m]'
        XB6: UnitValue = '-0.1 [m]'
        YB6: UnitValue = '0.1 [m]'
        XB7: UnitValue = '-0.1 [m]'
        YB7: UnitValue = '0.1 [m]'
        XB8: UnitValue = '-0.1 [m]'
        YB8: UnitValue = '0.1 [m]'
        XB9: UnitValue = '-0.1 [m]'
        YB9: UnitValue = '0.1 [m]'
        XB10: UnitValue = '-0.1 [m]'
        YB10: UnitValue = '0.1 [m]'
        XB11: UnitValue = '-0.1 [m]'
        YB11: UnitValue = '0.1 [m]'
        XB12: UnitValue = '-0.1 [m]'
        YB12: UnitValue = '0.1 [m]'
        XB13: UnitValue = '-0.1 [m]'
        YB13: UnitValue = '0.1 [m]'
        XB14: UnitValue = '-0.1 [m]'
        YB14: UnitValue = '0.1 [m]'
        XB15: UnitValue = '-0.1 [m]'
        YB15: UnitValue = '0.1 [m]'

        # Ground Wire Data
        NG: Choice.ints(0, 1, 2) = 2
        GDataType: Choice.enum('from library file', 'direct') = 1
        GLName: str = '..\\conductor.clb'
        GWSame: IntBool = 1
        ElimGW: IntBool = 1
        GName: str = '1/2_HighStrengthSteel'
        G2Name: str = '1/2_HighStrengthSteel'
        RadiusG: UnitValue = '0.0055245 [m]'
        DCResG: UnitValue = '2.8645 [ohm/km]'
        PERMG: float = 1.0
        RadiusG2: UnitValue = '0.0055245 [m]'
        DCResG2: UnitValue = '2.8645 [ohm/km]'
        PERMG2: float = 1.0
        SAGG: UnitValue = '10.0 [m]'

        # Phase/Node Connection Information
        NC1: int = 1
        NC2: int = 2
        NC3: int = 3
        NG1: int = 4
        NG2: int = 5


@project_lookup.defn('master:Line_Tower_6_Concent')
class Tower6Concent(TWMCmp):
    _defn = 'master:Line_Tower_6_Concent'

    class Parameters(ParametersBase):

        # Configuration
        X: UnitValue = '0.0 [m]'
        Y: UnitValue = '30.0 [m]'
        XC: UnitValue = '10.0 [m]'
        X2: UnitValue = '2.0 [m]'
        Y2: UnitValue = '5.0 [m]'
        YG: UnitValue = '15.0 [m]'
        XG: UnitValue = '10.0 [m]'
        SHSag: IntBool = 0
        Transp: Choice.enum('disabled', 'enabled (all 6 together)', 'enabled (left 3, right 3 separately)') = 0
        ShuntG: UnitValue = '1.0E-11 [mho/m]'
        TName: str = '3L12'

        # Conductor Data
        CName: str = 'chukar'
        CDataType: Choice.enum('from library file', 'direct') = 1
        CLName: str = '..\\conductor.clb'
        Hollow: Choice.enum('solid core', 'hollow', 'stranded') = 0
        RadiusC: UnitValue = '0.0203454 [m]'
        RadiusCin: UnitValue = '0.0 [m]'
        num_tot_strnd: int = 19
        num_out_strnd: int = 12
        RadiusS: UnitValue = '0.003 [m]'
        DCResC: UnitValue = '0.03206 [ohm/km]'
        PERMC: float = 1.0
        SAGC: UnitValue = '10.0 [m]'
        NCondB: Choice.ints(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15) = 1
        BundSym: Choice.enum('symmetrical', 'asymmetrical') = 0
        BSP: UnitValue = '0.4572 [m]'
        SHBund: IntBool = 1

        # Asymmetrical Bundling Position Data
        XB1: UnitValue = '-0.1 [m]'
        YB1: UnitValue = '0.1 [m]'
        XB2: UnitValue = '-0.1 [m]'
        YB2: UnitValue = '0.1 [m]'
        XB3: UnitValue = '-0.1 [m]'
        YB3: UnitValue = '0.1 [m]'
        XB4: UnitValue = '-0.1 [m]'
        YB4: UnitValue = '0.1 [m]'
        XB5: UnitValue = '-0.1 [m]'
        YB5: UnitValue = '0.1 [m]'
        XB6: UnitValue = '-0.1 [m]'
        YB6: UnitValue = '0.1 [m]'
        XB7: UnitValue = '-0.1 [m]'
        YB7: UnitValue = '0.1 [m]'
        XB8: UnitValue = '-0.1 [m]'
        YB8: UnitValue = '0.1 [m]'
        XB9: UnitValue = '-0.1 [m]'
        YB9: UnitValue = '0.1 [m]'
        XB10: UnitValue = '-0.1 [m]'
        YB10: UnitValue = '0.1 [m]'
        XB11: UnitValue = '-0.1 [m]'
        YB11: UnitValue = '0.1 [m]'
        XB12: UnitValue = '-0.1 [m]'
        YB12: UnitValue = '0.1 [m]'
        XB13: UnitValue = '-0.1 [m]'
        YB13: UnitValue = '0.1 [m]'
        XB14: UnitValue = '-0.1 [m]'
        YB14: UnitValue = '0.1 [m]'
        XB15: UnitValue = '-0.1 [m]'
        YB15: UnitValue = '0.1 [m]'

        # Ground Wire Data
        NG: Choice.ints(0, 1, 2) = 2
        GDataType: Choice.enum('from library file', 'direct') = 1
        GLName: str = '..\\conductor.clb'
        GWSame: IntBool = 1
        ElimGW: IntBool = 1
        GName: str = '1/2_HighStrengthSteel'
        G2Name: str = '1/2_HighStrengthSteel'
        RadiusG: UnitValue = '0.0055245 [m]'
        DCResG: UnitValue = '2.8645 [ohm/km]'
        PERMG: float = 1.0
        RadiusG2: UnitValue = '0.0055245 [m]'
        DCResG2: UnitValue = '2.8645 [ohm/km]'
        PERMG2: float = 1.0
        SAGG: UnitValue = '10.0 [m]'

        # Phase/Node Connection Information
        NC1: int = 1
        NC2: int = 2
        NC3: int = 3
        NC4: int = 4
        NC5: int = 5
        NC6: int = 6
        NG1: int = 7
        NG2: int = 8


@project_lookup.defn('master:Line_Tower_6_Delta')
class Tower6Delta(TWMCmp):
    _defn = 'master:Line_Tower_6_Delta'

    class Parameters(ParametersBase):

        # Configuration
        X: UnitValue = '0.0 [m]'
        Y: UnitValue = '30.0 [m]'
        XC: UnitValue = '10.0 [m]'
        X2: UnitValue = '2.0 [m]'
        Y2: UnitValue = '5.0 [m]'
        YG: UnitValue = '10.0 [m]'
        XG: UnitValue = '10.0 [m]'
        SHSag: IntBool = 0
        Transp: Choice.enum('disabled', 'enabled (all 6 together)', 'enabled (left 3, right 3 separately)') = 0
        ShuntG: UnitValue = '1.0E-11 [mho/m]'
        TName: str = '3L14'

        # Conductor Data
        CName: str = 'chukar'
        CDataType: Choice.enum('from library file', 'direct') = 1
        CLName: str = '..\\conductor.clb'
        Hollow: Choice.enum('solid core', 'hollow', 'stranded') = 0
        RadiusC: UnitValue = '0.0203454 [m]'
        RadiusCin: UnitValue = '0.0 [m]'
        num_tot_strnd: int = 19
        num_out_strnd: int = 12
        RadiusS: UnitValue = '0.003 [m]'
        DCResC: UnitValue = '0.03206 [ohm/km]'
        PERMC: float = 1.0
        SAGC: UnitValue = '10.0 [m]'
        NCondB: Choice.ints(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15) = 1
        BundSym: Choice.enum('symmetrical', 'asymmetrical') = 0
        BSP: UnitValue = '0.4572 [m]'
        SHBund: IntBool = 1

        # Asymmetrical Bundling Position Data
        XB1: UnitValue = '-0.1 [m]'
        YB1: UnitValue = '0.1 [m]'
        XB2: UnitValue = '-0.1 [m]'
        YB2: UnitValue = '0.1 [m]'
        XB3: UnitValue = '-0.1 [m]'
        YB3: UnitValue = '0.1 [m]'
        XB4: UnitValue = '-0.1 [m]'
        YB4: UnitValue = '0.1 [m]'
        XB5: UnitValue = '-0.1 [m]'
        YB5: UnitValue = '0.1 [m]'
        XB6: UnitValue = '-0.1 [m]'
        YB6: UnitValue = '0.1 [m]'
        XB7: UnitValue = '-0.1 [m]'
        YB7: UnitValue = '0.1 [m]'
        XB8: UnitValue = '-0.1 [m]'
        YB8: UnitValue = '0.1 [m]'
        XB9: UnitValue = '-0.1 [m]'
        YB9: UnitValue = '0.1 [m]'
        XB10: UnitValue = '-0.1 [m]'
        YB10: UnitValue = '0.1 [m]'
        XB11: UnitValue = '-0.1 [m]'
        YB11: UnitValue = '0.1 [m]'
        XB12: UnitValue = '-0.1 [m]'
        YB12: UnitValue = '0.1 [m]'
        XB13: UnitValue = '-0.1 [m]'
        YB13: UnitValue = '0.1 [m]'
        XB14: UnitValue = '-0.1 [m]'
        YB14: UnitValue = '0.1 [m]'
        XB15: UnitValue = '-0.1 [m]'
        YB15: UnitValue = '0.1 [m]'

        # Ground Wire Data
        NG: Choice.ints(0, 1, 2) = 2
        GDataType: Choice.enum('from library file', 'direct') = 1
        GLName: str = '..\\conductor.clb'
        GWSame: IntBool = 1
        ElimGW: IntBool = 1
        GName: str = '1/2_HighStrengthSteel'
        G2Name: str = '1/2_HighStrengthSteel'
        RadiusG: UnitValue = '0.0055245 [m]'
        DCResG: UnitValue = '2.8645 [ohm/km]'
        PERMG: float = 1.0
        RadiusG2: UnitValue = '0.0055245 [m]'
        DCResG2: UnitValue = '2.8645 [ohm/km]'
        PERMG2: float = 1.0
        SAGG: UnitValue = '10.0 [m]'

        # Phase/Node Connection Information
        NC1: int = 1
        NC2: int = 2
        NC3: int = 3
        NC4: int = 4
        NC5: int = 5
        NC6: int = 6
        NG1: int = 7
        NG2: int = 8


@project_lookup.defn('master:Line_Tower_6_Flat')
class Tower6Flat(TWMCmp):
    _defn = 'master:Line_Tower_6_Flat'

    class Parameters(ParametersBase):

        # Configuration
        X: UnitValue = '0.0 [m]'
        Y: UnitValue = '30.0 [m]'
        XC: UnitValue = '10.0 [m]'
        Y2: UnitValue = '5.0 [m]'
        YG: UnitValue = '10.0 [m]'
        XG: UnitValue = '10.0 [m]'
        SHSag: IntBool = 0
        Transp: Choice.enum('disabled', 'enabled (all 6 together)', 'enabled (top 3, bottom 3 separately)') = 0
        ShuntG: UnitValue = '1.0E-11 [mho/m]'
        TName: str = '3L6'

        # Conductor Data
        CName: str = 'chukar'
        CDataType: Choice.enum('from library file', 'direct') = 1
        CLName: str = '..\\conductor.clb'
        Hollow: Choice.enum('solid core', 'hollow', 'stranded') = 0
        RadiusC: UnitValue = '0.0203454 [m]'
        RadiusCin: UnitValue = '0.0 [m]'
        num_tot_strnd: int = 19
        num_out_strnd: int = 12
        RadiusS: UnitValue = '0.003 [m]'
        DCResC: UnitValue = '0.03206 [ohm/km]'
        PERMC: float = 1.0
        SAGC: UnitValue = '10.0 [m]'
        NCondB: Choice.ints(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15) = 1
        BundSym: Choice.enum('symmetrical', 'asymmetrical') = 0
        BSP: UnitValue = '0.4572 [m]'
        SHBund: IntBool = 1

        # Asymmetrical Bundling Position Data
        XB1: UnitValue = '-0.1 [m]'
        YB1: UnitValue = '0.1 [m]'
        XB2: UnitValue = '-0.1 [m]'
        YB2: UnitValue = '0.1 [m]'
        XB3: UnitValue = '-0.1 [m]'
        YB3: UnitValue = '0.1 [m]'
        XB4: UnitValue = '-0.1 [m]'
        YB4: UnitValue = '0.1 [m]'
        XB5: UnitValue = '-0.1 [m]'
        YB5: UnitValue = '0.1 [m]'
        XB6: UnitValue = '-0.1 [m]'
        YB6: UnitValue = '0.1 [m]'
        XB7: UnitValue = '-0.1 [m]'
        YB7: UnitValue = '0.1 [m]'
        XB8: UnitValue = '-0.1 [m]'
        YB8: UnitValue = '0.1 [m]'
        XB9: UnitValue = '-0.1 [m]'
        YB9: UnitValue = '0.1 [m]'
        XB10: UnitValue = '-0.1 [m]'
        YB10: UnitValue = '0.1 [m]'
        XB11: UnitValue = '-0.1 [m]'
        YB11: UnitValue = '0.1 [m]'
        XB12: UnitValue = '-0.1 [m]'
        YB12: UnitValue = '0.1 [m]'
        XB13: UnitValue = '-0.1 [m]'
        YB13: UnitValue = '0.1 [m]'
        XB14: UnitValue = '-0.1 [m]'
        YB14: UnitValue = '0.1 [m]'
        XB15: UnitValue = '-0.1 [m]'
        YB15: UnitValue = '0.1 [m]'

        # Ground Wire Data
        NG: Choice.ints(0, 1, 2) = 2
        GDataType: Choice.enum('from library file', 'direct') = 1
        GLName: str = '..\\conductor.clb'
        GWSame: IntBool = 1
        ElimGW: IntBool = 1
        GName: str = '1/2_HighStrengthSteel'
        G2Name: str = '1/2_HighStrengthSteel'
        RadiusG: UnitValue = '0.0055245 [m]'
        DCResG: UnitValue = '2.8645 [ohm/km]'
        PERMG: float = 1.0
        RadiusG2: UnitValue = '0.0055245 [m]'
        DCResG2: UnitValue = '2.8645 [ohm/km]'
        PERMG2: float = 1.0
        SAGG: UnitValue = '10.0 [m]'

        # Phase/Node Connection Information
        NC1: int = 1
        NC2: int = 2
        NC3: int = 3
        NC4: int = 4
        NC5: int = 5
        NC6: int = 6
        NG1: int = 7
        NG2: int = 8


@project_lookup.defn('master:Line_Tower_6_Offset')
class Tower6Offset(TWMCmp):
    _defn = 'master:Line_Tower_6_Offset'

    class Parameters(ParametersBase):

        # Configuration
        X: UnitValue = '0.0 [m]'
        Y: UnitValue = '30.0 [m]'
        XC: UnitValue = '10.0 [m]'
        X2: UnitValue = '2.0 [m]'
        Y2: UnitValue = '5.0 [m]'
        YG: UnitValue = '10.0 [m]'
        XG: UnitValue = '10.0 [m]'
        SHSag: IntBool = 0
        Transp: Choice.enum('disabled', 'enabled (all 6 together)', 'enabled (left 3, right 3 separately)') = 0
        ShuntG: UnitValue = '1.0E-11 [mho/m]'
        TName: str = '3L13'

        # Conductor Data
        CName: str = 'chukar'
        CDataType: Choice.enum('from library file', 'direct') = 1
        CLName: str = '..\\conductor.clb'
        Hollow: Choice.enum('solid core', 'hollow', 'stranded') = 0
        RadiusC: UnitValue = '0.0203454 [m]'
        RadiusCin: UnitValue = '0.0 [m]'
        num_tot_strnd: int = 19
        num_out_strnd: int = 12
        RadiusS: UnitValue = '0.003 [m]'
        DCResC: UnitValue = '0.03206 [ohm/km]'
        PERMC: float = 1.0
        SAGC: UnitValue = '10.0 [m]'
        NCondB: Choice.ints(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15) = 1
        BundSym: Choice.enum('symmetrical', 'asymmetrical') = 0
        BSP: UnitValue = '0.4572 [m]'
        SHBund: IntBool = 1

        # Asymmetrical Bundling Position Data
        XB1: UnitValue = '-0.1 [m]'
        YB1: UnitValue = '0.1 [m]'
        XB2: UnitValue = '-0.1 [m]'
        YB2: UnitValue = '0.1 [m]'
        XB3: UnitValue = '-0.1 [m]'
        YB3: UnitValue = '0.1 [m]'
        XB4: UnitValue = '-0.1 [m]'
        YB4: UnitValue = '0.1 [m]'
        XB5: UnitValue = '-0.1 [m]'
        YB5: UnitValue = '0.1 [m]'
        XB6: UnitValue = '-0.1 [m]'
        YB6: UnitValue = '0.1 [m]'
        XB7: UnitValue = '-0.1 [m]'
        YB7: UnitValue = '0.1 [m]'
        XB8: UnitValue = '-0.1 [m]'
        YB8: UnitValue = '0.1 [m]'
        XB9: UnitValue = '-0.1 [m]'
        YB9: UnitValue = '0.1 [m]'
        XB10: UnitValue = '-0.1 [m]'
        YB10: UnitValue = '0.1 [m]'
        XB11: UnitValue = '-0.1 [m]'
        YB11: UnitValue = '0.1 [m]'
        XB12: UnitValue = '-0.1 [m]'
        YB12: UnitValue = '0.1 [m]'
        XB13: UnitValue = '-0.1 [m]'
        YB13: UnitValue = '0.1 [m]'
        XB14: UnitValue = '-0.1 [m]'
        YB14: UnitValue = '0.1 [m]'
        XB15: UnitValue = '-0.1 [m]'
        YB15: UnitValue = '0.1 [m]'

        # Ground Wire Data
        NG: Choice.ints(0, 1, 2) = 2
        GDataType: Choice.enum('from library file', 'direct') = 1
        GLName: str = '..\\conductor.clb'
        GWSame: IntBool = 1
        ElimGW: IntBool = 1
        GName: str = '1/2_HighStrengthSteel'
        G2Name: str = '1/2_HighStrengthSteel'
        RadiusG: UnitValue = '0.0055245 [m]'
        DCResG: UnitValue = '2.8645 [ohm/km]'
        PERMG: float = 1.0
        RadiusG2: UnitValue = '0.0055245 [m]'
        DCResG2: UnitValue = '2.8645 [ohm/km]'
        PERMG2: float = 1.0
        SAGG: UnitValue = '10.0 [m]'

        # Phase/Node Connection Information
        NC1: int = 1
        NC2: int = 2
        NC3: int = 3
        NC4: int = 4
        NC5: int = 5
        NC6: int = 6
        NG1: int = 7
        NG2: int = 8


@project_lookup.defn('master:LIne_Tower_6_Vert')
class Tower6Vert(TWMCmp):
    _defn = 'master:LIne_Tower_6_Vert'

    class Parameters(ParametersBase):

        # Configuration
        X: UnitValue = '0.0 [m]'
        Y: UnitValue = '30.0 [m]'
        XC: UnitValue = '10.0 [m]'
        Y2: UnitValue = '5.0 [m]'
        YG: UnitValue = '15.0 [m]'
        XG: UnitValue = '10.0 [m]'
        SHSag: IntBool = 0
        Transp: Choice.enum('disabled', 'enabled (all 6 together)', 'enabled (left 3, right 3 separately)') = 0
        ShuntG: UnitValue = '1.0E-11 [mho/m]'
        TName: str = 'H-Frame-3H4'

        # Conductor Data
        CName: str = 'chukar'
        CDataType: Choice.enum('from library file', 'direct') = 1
        CLName: str = '..\\conductor.clb'
        Hollow: Choice.enum('solid core', 'hollow', 'stranded') = 0
        RadiusC: UnitValue = '0.0203454 [m]'
        RadiusCin: UnitValue = '0.0 [m]'
        num_tot_strnd: int = 19
        num_out_strnd: int = 12
        RadiusS: UnitValue = '0.003 [m]'
        DCResC: UnitValue = '0.03206 [ohm/km]'
        PERMC: float = 1.0
        SAGC: UnitValue = '10.0 [m]'
        NCondB: Choice.ints(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15) = 1
        BundSym: Choice.enum('symmetrical', 'asymmetrical') = 0
        BSP: UnitValue = '0.4572 [m]'
        SHBund: IntBool = 1

        # Asymmetrical Bundling Position Data
        XB12: UnitValue = '-0.1 [m]'
        XB1: UnitValue = '-0.1 [m]'
        YB1: UnitValue = '0.1 [m]'
        XB2: UnitValue = '-0.1 [m]'
        YB2: UnitValue = '0.1 [m]'
        XB3: UnitValue = '-0.1 [m]'
        YB3: UnitValue = '0.1 [m]'
        XB4: UnitValue = '-0.1 [m]'
        YB4: UnitValue = '0.1 [m]'
        XB5: UnitValue = '-0.1 [m]'
        YB5: UnitValue = '0.1 [m]'
        XB6: UnitValue = '-0.1 [m]'
        YB6: UnitValue = '0.1 [m]'
        XB7: UnitValue = '-0.1 [m]'
        YB7: UnitValue = '0.1 [m]'
        XB8: UnitValue = '-0.1 [m]'
        YB8: UnitValue = '0.1 [m]'
        XB9: UnitValue = '-0.1 [m]'
        YB9: UnitValue = '0.1 [m]'
        XB10: UnitValue = '-0.1 [m]'
        YB10: UnitValue = '0.1 [m]'
        XB11: UnitValue = '-0.1 [m]'
        YB11: UnitValue = '0.1 [m]'
        YB12: UnitValue = '0.1 [m]'
        XB13: UnitValue = '-0.1 [m]'
        YB13: UnitValue = '0.1 [m]'
        XB14: UnitValue = '-0.1 [m]'
        YB14: UnitValue = '0.1 [m]'
        XB15: UnitValue = '-0.1 [m]'
        YB15: UnitValue = '0.1 [m]'

        # Ground Wire Data
        NG: Choice.ints(0, 1, 2) = 2
        GDataType: Choice.enum('from library file', 'direct') = 1
        GLName: str = '..\\conductor.clb'
        GWSame: IntBool = 1
        ElimGW: IntBool = 1
        GName: str = '1/2_HighStrengthSteel'
        G2Name: str = '1/2_HighStrengthSteel'
        RadiusG: UnitValue = '0.0055245 [m]'
        DCResG: UnitValue = '2.8645 [ohm/km]'
        PERMG: float = 1.0
        RadiusG2: UnitValue = '0.0055245 [m]'
        DCResG2: UnitValue = '2.8645 [ohm/km]'
        PERMG2: float = 1.0
        SAGG: UnitValue = '10.0 [m]'

        # Phase/Node Connection Information
        NC1: int = 1
        NC2: int = 2
        NC3: int = 3
        NC4: int = 4
        NC5: int = 5
        NC6: int = 6
        NG1: int = 7
        NG2: int = 8


@project_lookup.defn('master:Line_Tower_6_Vert1')
class Tower6Vert1(TWMCmp):
    _defn = 'master:Line_Tower_6_Vert1'

    class Parameters(ParametersBase):

        # Configuration
        X: UnitValue = '0.0 [m]'
        Y: UnitValue = '30.0 [m]'
        Y2: UnitValue = '5.0 [m]'
        Y3: UnitValue = '15.0 [m]'
        YG: UnitValue = '30.0 [m]'
        XG: UnitValue = '10.0 [m]'
        SHSag: IntBool = 0
        Transp: Choice.enum('disabled', 'enabled (all together)', 'enabled (each group separately)') = 0
        ShuntG: UnitValue = '1.0E-11 [mho/m]'
        TName: str = 'N6'
        XG_2: UnitValue = '0.0 [m]'

        # Conductor Data
        CName: str = 'chukar'
        CDataType: Choice.enum('from library file', 'direct') = 1
        CLName: str = '..\\conductor.clb'
        Hollow: Choice.enum('solid core', 'hollow', 'stranded') = 0
        RadiusC: UnitValue = '0.0203454 [m]'
        RadiusCin: UnitValue = '0.0 [m]'
        num_tot_strnd: int = 19
        num_out_strnd: int = 12
        RadiusS: UnitValue = '0.003 [m]'
        DCResC: UnitValue = '0.03206 [ohm/km]'
        PERMC: float = 1.0
        SAGC: UnitValue = '10.0 [m]'
        NCondB: Choice.ints(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15) = 1
        BundSym: Choice.enum('symmetrical', 'asymmetrical') = 0
        BSP: UnitValue = '0.4572 [m]'
        SHBund: IntBool = 1

        # Asymmetrical Bundling Position Data
        XB1: UnitValue = '-0.1 [m]'
        YB1: UnitValue = '0.1 [m]'
        XB2: UnitValue = '-0.1 [m]'
        YB2: UnitValue = '0.1 [m]'
        XB3: UnitValue = '-0.1 [m]'
        YB3: UnitValue = '0.1 [m]'
        XB4: UnitValue = '-0.1 [m]'
        YB4: UnitValue = '0.1 [m]'
        XB5: UnitValue = '-0.1 [m]'
        YB5: UnitValue = '0.1 [m]'
        XB6: UnitValue = '-0.1 [m]'
        YB6: UnitValue = '0.1 [m]'
        XB7: UnitValue = '-0.1 [m]'
        YB7: UnitValue = '0.1 [m]'
        XB8: UnitValue = '-0.1 [m]'
        YB8: UnitValue = '0.1 [m]'
        XB9: UnitValue = '-0.1 [m]'
        YB9: UnitValue = '0.1 [m]'
        XB10: UnitValue = '-0.1 [m]'
        YB10: UnitValue = '0.1 [m]'
        XB11: UnitValue = '-0.1 [m]'
        YB11: UnitValue = '0.1 [m]'
        XB12: UnitValue = '-0.1 [m]'
        YB12: UnitValue = '0.1 [m]'
        XB13: UnitValue = '-0.1 [m]'
        YB13: UnitValue = '0.1 [m]'
        XB14: UnitValue = '-0.1 [m]'
        YB14: UnitValue = '0.1 [m]'
        XB15: UnitValue = '-0.1 [m]'
        YB15: UnitValue = '0.1 [m]'

        # Ground Wire Data
        NG: Choice.ints(0, 1, 2) = 2
        GDataType: Choice.enum('from library file', 'direct') = 1
        GLName: str = '..\\conductor.clb'
        GWSame: IntBool = 1
        ElimGW: IntBool = 1
        GName: str = '1/2_HighStrengthSteel'
        G2Name: str = '1/2_HighStrengthSteel'
        RadiusG: UnitValue = '0.0055245 [m]'
        DCResG: UnitValue = '2.8645 [ohm/km]'
        PERMG: float = 1.0
        RadiusG2: UnitValue = '0.0055245 [m]'
        DCResG2: UnitValue = '2.8645 [ohm/km]'
        PERMG2: float = 1.0
        SAGG: UnitValue = '10.0 [m]'

        # Phase/Node Connection Information
        NC1: int = 1
        NC2: int = 2
        NC3: int = 3
        NC4: int = 4
        NC5: int = 5
        NC6: int = 6
        NG1: int = 7
        NG2: int = 8


@project_lookup.defn('master:Line_Tower_Universal')
class TowerUniversal(TWMCmp):
    _defn = 'master:Line_Tower_Universal'

    class Parameters(ParametersBase):

        # Configuration
        TName: str = '3H5'
        Nc: Choice.ints(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12) = 3
        Transp: IntBool = 1
        STL: Choice.enum('No, all together', 'Yes, separate circuits') = 0
        ShuntG: UnitValue = '1.0E-11 [mho/m]'
        SHSag: IntBool = 0
        X: UnitValue = '0.0 [m]'

        # Conductor Data
        CName: str = 'chukar'
        CDataType: Choice.enum('from library file', 'direct') = 1
        CLName: str = '..\\conductor.clb'
        Hollow: Choice.enum('solid core', 'hollow', 'stranded') = 0
        RadiusC: UnitValue = '0.0203454 [m]'
        RadiusCin: UnitValue = '0.0 [m]'
        num_tot_strnd: int = 19
        num_out_strnd: int = 12
        RadiusS: UnitValue = '0.003 [m]'
        DCResC: UnitValue = '0.03206 [ohm/km]'
        PERMC: float = 1.0
        SAGC: UnitValue = '10.0 [m]'
        NCondB: Choice.ints(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15) = 1
        BundSym: Choice.enum('symmetrical', 'asymmetrical') = 0
        BSP: UnitValue = '0.4572 [m]'
        SHBund: IntBool = 1

        # Conductor Coordinates
        XC1: UnitValue = '-5 [m]'
        YC1: UnitValue = '30 [m]'
        XC2: UnitValue = '0 [m]'
        YC2: UnitValue = '30 [m]'
        XC3: UnitValue = '5 [m]'
        YC3: UnitValue = '30 [m]'
        XC4: UnitValue = '10 [m]'
        YC4: UnitValue = '30 [m]'
        XC5: UnitValue = '15 [m]'
        YC5: UnitValue = '30 [m]'
        XC6: UnitValue = '20 [m]'
        YC6: UnitValue = '30 [m]'
        XC7: UnitValue = '25 [m]'
        YC7: UnitValue = '30 [m]'
        XC8: UnitValue = '30 [m]'
        YC8: UnitValue = '30 [m]'
        XC9: UnitValue = '35 [m]'
        YC9: UnitValue = '30 [m]'
        XC10: UnitValue = '40 [m]'
        YC10: UnitValue = '30 [m]'
        XC11: UnitValue = '45 [m]'
        YC11: UnitValue = '30 [m]'
        XC12: UnitValue = '50 [m]'
        YC12: UnitValue = '30 [m]'

        # Asymmetrical Bundling Position Data
        XB1: UnitValue = '-0.1 [m]'
        YB1: UnitValue = '0.1 [m]'
        XB2: UnitValue = '-0.1 [m]'
        YB2: UnitValue = '0.1 [m]'
        XB3: UnitValue = '-0.1 [m]'
        YB3: UnitValue = '0.1 [m]'
        XB4: UnitValue = '-0.1 [m]'
        YB4: UnitValue = '0.1 [m]'
        XB5: UnitValue = '-0.1 [m]'
        YB5: UnitValue = '0.1 [m]'
        XB6: UnitValue = '-0.1 [m]'
        YB6: UnitValue = '0.1 [m]'
        XB7: UnitValue = '-0.1 [m]'
        YB7: UnitValue = '0.1 [m]'
        XB8: UnitValue = '-0.1 [m]'
        YB8: UnitValue = '0.1 [m]'
        XB9: UnitValue = '-0.1 [m]'
        YB9: UnitValue = '0.1 [m]'
        XB10: UnitValue = '-0.1 [m]'
        YB10: UnitValue = '0.1 [m]'
        XB11: UnitValue = '-0.1 [m]'
        YB11: UnitValue = '0.1 [m]'
        XB12: UnitValue = '-0.1 [m]'
        YB12: UnitValue = '0.1 [m]'
        XB13: UnitValue = '-0.1 [m]'
        YB13: UnitValue = '0.1 [m]'
        XB14: UnitValue = '-0.1 [m]'
        YB14: UnitValue = '0.1 [m]'
        XB15: UnitValue = '-0.1 [m]'
        YB15: UnitValue = '0.1 [m]'

        # Ground Wire Data
        NG: Choice.ints(0, 1, 2) = 2
        GDataType: Choice.enum('from library file', 'direct') = 1
        GLName: str = '..\\conductor.clb'
        GWSame: IntBool = 1
        ElimGW: IntBool = 1
        GName: str = '1/2_HighStrengthSteel'
        G2Name: str = '1/2_HighStrengthSteel'
        RadiusG: UnitValue = '0.0055245 [m]'
        DCResG: UnitValue = '2.8645 [ohm/km]'
        PERMG: float = 1.0
        RadiusG2: UnitValue = '0.0055245 [m]'
        DCResG2: UnitValue = '2.8645 [ohm/km]'
        PERMG2: float = 1.0
        SAGG: UnitValue = '10.0 [m]'

        # Ground Wires Coordinates
        XG1: UnitValue = '-2.5 [m]'
        YG1: UnitValue = '40 [m]'
        XG2: UnitValue = '2.5 [m]'
        YG2: UnitValue = '40 [m]'

        # Phase/Node Connection Information
        NC1: int = 1
        NC2: int = 2
        NC3: int = 3
        NC4: int = 4
        NC5: int = 5
        NC6: int = 6
        NC7: int = 7
        NC8: int = 8
        NC9: int = 9
        NC10: int = 10
        NC11: int = 11
        NC12: int = 12
        NG1: int = 4
        NG2: int = 5


__all__ = ['TWMCmp', 'BergOptions', 'BusWork1', 'BusWork3H', 'BusWork3V', 'ConstantsDebug', 'FreDepOptions', 'FrePhaseOptions', 'Ground', 'ManualYZ', 'OutDisp', 'Tower1', 'Tower12Vert', 'Tower2Flat', 'Tower3Flat', 'Tower3Concent', 'Tower3Delta', 'Tower3Offset', 'Tower3Vert', 'Tower6Concent', 'Tower6Delta', 'Tower6Flat', 'Tower6Offset', 'Tower6Vert', 'Tower6Vert1', 'TowerUniversal']
